@@ -690,9 +690,6 @@ class DevMgr5(QMainWindow,  Ui_MainWindow):
 
                 self.DeviceList.updateGeometry()
                 qApp.processEvents()
-                # sending Event to remove this device from hp-systray
-                if removed_device:
-                    utils.sendEvent(EVENT_CUPS_QUEUES_CHANGED,removed_device, "")
 
                 if len(device_list):
                     for tab in self.TabIndex:
@@ -1433,18 +1430,20 @@ class DevMgr5(QMainWindow,  Ui_MainWindow):
         light_magenta = "#ffccff"
         black = "#000000"
         blue = "#0000ff"
-        dark_grey = "#808080"
-        light_grey = "#c0c0c0"
+        gray = "#808080"
+        dark_gray = "#a9a9a9"
+        light_gray = "#c0c0c0"
+        red = "#ff0000"
 
         self.TYPE_TO_PIX_MAP = {
                                AGENT_TYPE_UNSPECIFIED : [black],
                                AGENT_TYPE_BLACK: [black],
                                AGENT_TYPE_MATTE_BLACK : [black],
-                               AGENT_TYPE_PHOTO_BLACK : [dark_grey],
+                               AGENT_TYPE_PHOTO_BLACK : [dark_gray],
                                AGENT_TYPE_BLACK_B8800: [black],
                                AGENT_TYPE_CMY: [cyan, magenta, yellow],
                                AGENT_TYPE_KCM: [light_cyan, light_magenta, light_yellow],
-                               AGENT_TYPE_GGK: [dark_grey],
+                               AGENT_TYPE_GGK: [dark_gray],
                                AGENT_TYPE_YELLOW: [yellow],
                                AGENT_TYPE_MAGENTA: [magenta],
                                AGENT_TYPE_CYAN : [cyan],
@@ -1456,12 +1455,15 @@ class DevMgr5(QMainWindow,  Ui_MainWindow):
                                AGENT_TYPE_LC_LM: [light_cyan, light_magenta],
                                #AGENT_TYPE_Y_M: [yellow, magenta],
                                #AGENT_TYPE_C_K: [black, cyan],
-                               AGENT_TYPE_LG_PK: [light_grey, dark_grey],
-                               AGENT_TYPE_LG: [light_grey],
-                               AGENT_TYPE_G: [dark_grey],
-                               AGENT_TYPE_PG: [light_grey],
+                               AGENT_TYPE_LG_PK: [light_gray, dark_gray],
+                               AGENT_TYPE_LG: [light_gray],
+                               AGENT_TYPE_G: [gray],
+                               AGENT_TYPE_DG: [dark_gray],
+                               AGENT_TYPE_PG: [light_gray],
                                AGENT_TYPE_C_M: [cyan, magenta],
                                AGENT_TYPE_K_Y: [black, yellow],
+                               AGENT_TYPE_LC: [light_cyan],
+                               AGENT_TYPE_RED : [red],
                                }
 
         self.supplies_headers = [self.__tr(""), self.__tr("Description"),
